==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/group/input/updated/group/buckets/bucket/action/action/NxActionRegMoveRpcUpdateGroupUpdatedCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.group.input.updated.group.buckets.bucket.action.action;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-reg-move-rpc-update-group-updated-case {
 *   uses nx-action-reg-move-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/update-group/input/updated-group/buckets/bucket/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-reg-move-rpc-update-group-updated-case</i>
 *
 */
public interface NxActionRegMoveRpcUpdateGroupUpdatedCase
    extends
    DataObject,
    Augmentable<NxActionRegMoveRpcUpdateGroupUpdatedCase>,
    NxActionRegMoveGrouping,
    Action
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-reg-move-rpc-update-group-updated-case");


}

==> openflowplugin-extension-nicira-0.9.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/group/input/updated/group/buckets/bucket/action/action/NxActionRegMoveRpcUpdateGroupUpdatedCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.group.input.updated.group.buckets.bucket.action.action;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-reg-move-rpc-update-group-updated-case {
 *   uses nx-action-reg-move-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/update-group/input/updated-group/buckets/bucket/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-reg-move-rpc-update-group-updated-case</i>
 *
 */
public interface NxActionRegMoveRpcUpdateGroupUpdatedCase
    extends
    DataObject,
    Augmentable<NxActionRegMoveRpcUpdateGroupUpdatedCase>,
    NxActionRegMoveGrouping,
    Action
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-reg-move-rpc-update-group-updated-case");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.group.input.updated.group.buckets.bucket.action.action.NxActionRegMoveRpcUpdateGroupUpdatedCase> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.group.input.updated.group.buckets.bucket.action.action.NxActionRegMoveRpcUpdateGroupUpdatedCase.class;
    }

}
